@@ -213,7 +213,7 @@ as_tsibble.NULL <- function(x, ...) {
 #'   update_tsibble(index = Hour_Since)
 #'
 #' # update key: drop the variable "State" from the key
-#' tourism %>% 
+#' tourism %>%
 #'   update_tsibble(key = c(Purpose, Region))
 update_tsibble <- function(x, key, index, regular = is_regular(x),
                            validate = TRUE, .drop = key_drop_default(x)) {
@@ -301,8 +301,10 @@ build_tsibble <- function(x, key = NULL, key_data = NULL, index, index2 = index,
   if (!is_empty(is_index_in_keys)) {
     abort(sprintf("Column `%s` can't be both index and key.", idx_chr[[1]]))
   }
-  # arrange index from past to future for each key value
-  if (vec_size(tbl) == 0 || is_null(ordered)) { # first time to create a tsibble
+  if (vec_size(tbl) == 0) { # tibbles with no rows are trivially ordered
+    ordered <- TRUE
+  } else if (is_null(ordered)) { # first time to create a tsibble
+    # arrange index from past to future for each key value
     tbl <- arrange(tbl, !!!syms(key_vars), !!sym(index))
     ordered <- TRUE
   }
@@ -469,7 +471,7 @@ validate_tsibble <- function(data, key, index, key_data = NULL) {
   is_dup <- duplicated_key_index(data, key, index, key_data)
   if (is_dup) {
     abort(c(
-      "A valid tsibble must have distinct rows identified by key and index.", 
+      "A valid tsibble must have distinct rows identified by key and index.",
       i = "Please use `duplicates()` to check the duplicated rows."))
   }
   data
@@ -511,8 +513,7 @@ as_tibble.tbl_ts <- function(x, ...) {
 }
 
 as_tibble.grouped_ts <- function(x, ...) {
-  new_tibble(vec_data(x), nrow = nrow(x),
-    groups = group_data(x), class = "grouped_df")
+  new_grouped_df(x, groups = group_data(x))
 }
 
 as_tibble.grouped_df <- function(x, ...) {
