@@ -17,5 +17,8 @@
   s3_register("ggplot2::scale_type", "yearquarter")
   s3_register("ggplot2::scale_type", "yearmonth")
   s3_register("ggplot2::scale_type", "yearweek")
+  s3_register("scales::fullseq", "yearquarter")
+  s3_register("scales::fullseq", "yearmonth")
+  s3_register("scales::fullseq", "yearweek")
 }
 # nocov end
