@@ -7,8 +7,9 @@ test_that("multiple arguments matching", {
   expect_error(new_interval(hour = 1:2, minute = 30), "accepts one input")
 })
 
+int <- new_interval(hour = 1, minute = 30)
+
 test_that("interval class", {
-  int <- new_interval(hour = 1, minute = 30)
   expect_is(int, "interval")
   expect_equal(format(int), "1h 30m")
   expect_is(new_interval(), "interval")
@@ -16,3 +17,13 @@ test_that("interval class", {
   expect_is(new_interval(.regular = FALSE), "interval")
   expect_equal(format(new_interval(.regular = FALSE)), "!")
 })
+
+test_that("as.period() & as.duration()", {
+  expect_identical(
+    lubridate::as.period(int), lubridate::period(hour = 1, minute = 30)
+  )
+  expect_identical(
+    lubridate::as.duration(int),
+    lubridate::as.duration(lubridate::period(hour = 1, minute = 30))
+  )
+})
